!!****if* source/Simulation/SimulationMain/Sod/Simulation_init
!!
!! NAME
!!
!!  Simulation_init
!!
!!
!! SYNOPSIS
!!
!!  Simulation_init(integer(in) :: myPE)
!!
!!
!! DESCRIPTION
!!
!!  Initializes all the parameters needed for the Sod shock tube
!!  problem
!!
!! ARGUMENTS
!!
!!  myPE - the local processor number
!!
!! PARAMETERS
!!
!!
!!***

subroutine Simulation_init(myPE)
  
  use Simulation_data
  use RuntimeParameters_interface, ONLY : RuntimeParameters_get
  use Logfile_interface, ONLY : Logfile_stamp

  implicit none

#include "Flash.h"
#include "constants.h"
#include "Multispecies.h"
#include "Eos.h"

  integer, intent(in) :: myPE

  integer i
  character dummy

  call RuntimeParameters_get('smallx', sim_smallx)
  call RuntimeParameters_get('smallT', sim_smallT)
  call RuntimeParameters_get('rhoAmbient', sim_rhoAmb)
  call RuntimeParameters_get('eintAmbient',sim_eintAmb)
  call RuntimeParameters_get('tempAmbient',sim_tempAmb)
  call RuntimeParameters_get('presAmbient',sim_presAmb)
 
  call RuntimeParameters_get('filename', filename)

  open(42+myPE,file=filename,status='old',readonly)  
!  in here you would load the value:
  read(42+myPE,*) dummy
  read(42+myPE,*) sim_npart
  read(42+myPE,*) dummy
  read(42+myPE,*) dummy
  read(42+myPE,*) dummy

!  Then allocate the arrays
  allocate (sim_partPos(sim_npart,MDIM), sim_partVel(sim_npart,MDIM))
  allocate (sim_partM(sim_npart), sim_partH(sim_npart), sim_partU(sim_npart), &
            sim_partT(sim_npart), sim_partP(sim_npart), sim_partD(sim_npart))
  allocate (sim_xar36(sim_npart), sim_xc12(sim_npart), sim_xca40(sim_npart), &
            sim_xcr48(sim_npart), sim_xfe52(sim_npart), sim_xhe4(sim_npart), &
            sim_xmg24(sim_npart), sim_xne20(sim_npart), sim_xni56(sim_npart),&
            sim_xo16(sim_npart), sim_xs32(sim_npart), sim_xsi28(sim_npart), sim_xti44(sim_npart))

!  Then load the values for:
!      -sim_partPos
!      -sim_partVel
!      -sim_partM
!      -sim_partH
!      -sim_partU
!      -sim_x??? (abundances)

  do i=1,sim_npart

    read(42+myPE,*) sim_partPos(i,1), sim_partPos(i,2), sim_partPos(i,3), sim_partM(i), &
                    sim_partVel(i,1), sim_partVel(i,2), sim_partVel(i,3), sim_partU(i), &
                    sim_partH(i), sim_partD(i), sim_partP(i), sim_partT(i), &
                    sim_xhe4(i), sim_xc12(i) , sim_xo16(i) , sim_xne20(i), sim_xmg24(i), sim_xsi28(i), &
                    sim_xs32(i), sim_xar36(i), sim_xca40(i), sim_xti44(i), sim_xcr48(i), sim_xfe52(i), sim_xni56(i)

  enddo

  close(42+myPe)
    
  call Logfile_stamp(myPE, "initializing SPHinit problem",  &
       "[Simulation_init]")
     
end subroutine Simulation_init







